@@ -10,6 +10,7 @@
 #' columns represent variables.
 #' @param COV a \code{data.frame} or \code{matrix} of adjusting covariates. Rows represent samples, columns represent microbiome variables. 
 #' Can be \code{NULL}.
+#' @param scale logical. Should the function scale the data? Default = \code{TRUE}.
 #' @param FDPcut FDP (false discovery proportions) cutoff applied to define and select significant mediators. Default = \code{0.05}. 
 #' 
 #' @return A data.frame containing mediation testing results of selected mediators (FDP < \code{FDPcut}). 
@@ -29,48 +30,31 @@
 #' Stat Biosci. 2021. DOI: 10.1007/s12561-019-09253-3. PMID: 34093887; PMCID: PMC8177450.
 #' 
 #' @examples
-#' ## Generate simulated survival data
-#' n <- 200 # Sample size
-#' p <- 25 # Number of microbiome
-#' Treatment = rbinom(n, 1, 0.2) # binary outcome
-#'
-#' ## Generate two covariates, one binary, one continuous
-#' covariates = cbind(sample(c(1,0), n, replace = TRUE), rnorm(n))
-#' 
-#' ## parameters
-#' beta0 = as.numeric(matrix(0, 1, p))
-#' betaT = rep(0, p)
-#' betaT[c(1, 2, 3)] = c(1, 1.2, 1.5) # let the first three are non-zero
-#' betaX = matrix(0, p, 2)
-#' 
-#' alpha0 = 0
-#' alphaT = 1
-#' alphaZ = alphaC = rep(0, p)
-#' alphaZ[c(1, 2, 3)] = c(1.3, -0.7, -0.6) # let the first three are non-zero for response
-#' alphaX = c(0.5, 0.5)
-#' 
-#' ## Generate microbiome data
-#' X = cbind(rep(1, n), covariates, Treatment) # n * (1 + q + p)
-#' b = cbind(beta0, betaX, betaT) # p * (1 + q + p)
-#' gamma.simu = exp(X %*% t(b)) # n * p
-#' otu.com = t(apply(gamma.simu, 1, HIMA:::rdirichlet, n = 1)) # Dirichlet distribution
-#' 
-#' ## Generate outcome data
-#' X = cbind(rep(1, n),Treatment, covariates, log(otu.com), log(otu.com) * Treatment)
-#' b = c(alpha0, alphaT, alphaX, alphaZ, alphaC)
-#' outcome = c(b %*% t(X) + rnorm(n, mean = 0, sd = 1))
-#' exposure = t(t(Treatment))
-#' 
 #' \dontrun{
-#' microHIMA.fit <- microHIMA(X = exposure, Y = outcome, OTU = otu.com, COV = covariates)
+#' data(Example4)
+#' head(Example4$PhenoData)
+#' 
+#' microHIMA.fit <- microHIMA(X = Example4$PhenoData$Treatment, 
+#'                            Y = Example4$PhenoData$Outcome, 
+#'                            OTU = Example4$Mediator, 
+#'                            COV = Example4$PhenoData[, c("Sex", "Age")],
+#'                            scale = FALSE)
 #' microHIMA.fit
 #' }
 #' 
 #' @export
-microHIMA <- function(X, Y, OTU, COV = NULL, FDPcut = 0.05){
+microHIMA <- function(X, Y, OTU, COV = NULL, FDPcut = 0.05, scale = TRUE){
+  
+  X <- matrix(X, ncol = 1)
+  
+  M_raw <- as.matrix(OTU)
+  
+  M_ID_name <- colnames(M_raw)
+  if(is.null(M_ID_name)) M_ID_name <- seq_len(ncol(M_raw))
+  
+  if(!is.null(COV))
+    {COV <- as.matrix(COV); X <- cbind(X, COV)}
   
-  M_raw <- OTU
-  X <- cbind(X, COV)
   Y <- Y - mean(Y)
 
   M <- M_raw
@@ -86,8 +70,6 @@ microHIMA <- function(X, Y, OTU, COV = NULL, FDPcut = 0.05){
   P_raw_DLASSO <- matrix(0,1,d)
   M1 <- t(t(M_raw[,1]))
   
-  message("Running debiased Lasso...", "     (", Sys.time(), ")")
-  
   for (k in 1:d){
     M <- M_raw
     M[,1] <- M[,k]
@@ -101,10 +83,11 @@ microHIMA <- function(X, Y, OTU, COV = NULL, FDPcut = 0.05){
       }
     }
     
-    MT <- matrix(as.numeric(scale(MT)), nrow(scale(MT)), ncol(scale(MT)))
-    X <- matrix(as.numeric(scale(X)), nrow(scale(X)), ncol(scale(X)))
+    MT <- matrix(as.numeric(MT), nrow(MT))
     MX <- cbind(MT, X)
 
+    if(scale) MX <- scale(MX)
+    
     fit.dlasso  <- DLASSO_fun(MX, Y)
     
     beta_est <- fit.dlasso[1]
@@ -141,7 +124,7 @@ microHIMA <- function(X, Y, OTU, COV = NULL, FDPcut = 0.05){
   
   ID_FDR <- set[which(N0 > 0)]
 
-  out_result <- data.frame(ID = ID_FDR, 
+  out_result <- data.frame(ID = M_ID_name[ID_FDR], 
                            alpha = alpha_EST[ID_FDR], 
                            alpha_se = alpha_SE[ID_FDR], 
                            beta = beta_EST[ID_FDR], 
